
# sentry-dingtalk-new

| Version | Sentry Version |
|---- |----|
| 1.0.4 | 9.0.* |
| 1.1.0 | 9.1.* |

===============

配置sentry 钉钉报警通知

安装 - install 

```bash

- pip install sentry-dingtalk-new
```

* or docker 

```bash

  echo sentry-dingtalk-new >> requirements.txt
```

 重新构建或者重启(rebuild or reboot)

* sentry version: 9.0.0
* dingding webhook
* Sentry sending DingTalk. See https://www.dingtalk.com/
* DingTalk is a product of Alibaba Inc.